@@ -23,6 +23,7 @@ import os
 import re
 import threading
 import traceback
+import uuid
 import weakref
 
 from datetime import datetime, timedelta
@@ -508,7 +509,9 @@ class UpnpRootDevice(UpnpDevice, LandscapeDeviceExtension):
 
                 self._available = False
 
-                for svc_type in self._subscriptions:
+                subscription_type_list = [st for st in self._subscriptions.keys()]
+
+                for svc_type in subscription_type_list:
                     sub_sid, _ = self._subscriptions[svc_type]
 
                     if sub_sid in self._sid_to_service_lookup:
@@ -524,6 +527,7 @@ class UpnpRootDevice(UpnpDevice, LandscapeDeviceExtension):
                     )
                     self._logger.debug(dbgmsg)
                     del self._subscriptions[svc_type]
+
         finally:
             self._device_lock.release()
 
@@ -651,6 +655,11 @@ class UpnpRootDevice(UpnpDevice, LandscapeDeviceExtension):
             :param namespaces: A dictionary of namespaces to use when processing the device description.
         """
         try:
+            if self._ip_address is not None and self._ip_address != ipaddr:
+                self._logger.debug("UpnpRootDevice - IP Address change for device usn={} location={}.".format(
+                    self._usn, self._ip_address
+                ))
+
             self._ip_address = ipaddr
 
             specVerNode = docNode.find("specVersion", namespaces=namespaces)
