@@ -1,5 +1,5 @@
 
-from typing import List
+from typing import Any, List
 
 from enum import Enum
 
@@ -19,6 +19,11 @@ class Constraints(FeatureMask):
                          checkout=checkout, **kwargs)
         return
 
+    def __call__(self, **kwargs: Any):
+        inst = dict(self)
+        inst.update(kwargs)
+        return inst
+
 def merge_constraints(*args: Constraints) -> Constraints:
     """
         Takes a sequence of :class:`Contraints` objects and merges them into a single
